@@ -23,15 +23,17 @@ class Comic:
         except urllib2.HTTPError, he:
             raise FetchComicError, ('Unable to retrieve URL.', url, he.code)
 
-        if self.urlobj.headers.getmaintype() != 'image':
+        if self.urlobj.info().getmaintype() != 'image' and self.urlobj.info().gettype() != 'application/x-shockwave-flash':
             raise FetchComicError, ('No suitable image found to retrieve.', url)
 
         self.filename, self.ext = os.path.splitext(url.split('/')[-1])
         self.filename = filename or self.filename
         self.filename = self.filename.replace(os.sep, '_')
-        self.ext = '.' + self.urlobj.headers.getsubtype()
-        self.contentLength = int(self.urlobj.headers.get('content-length', 0))
-        self.lastModified = self.urlobj.headers.get('last-modified')
+        # Always use mime type for file extension if it is sane.
+        if self.urlobj.info().getmaintype() == 'image':
+            self.ext = '.' + self.urlobj.info().getsubtype()
+        self.contentLength = int(self.urlobj.info().get('content-length', 0))
+        self.lastModified = self.urlobj.info().get('last-modified')
         out.write('... filename = "%s", ext = "%s", contentLength = %d' % (self.filename, self.ext, self.contentLength), 2)
 
     def touch(self, filename):
