@@ -1,7 +1,6 @@
 import re
-import cgi
-import urllib
 from dosage.modules.helpers.BasicComicModule import BasicComicModule
+from dosage.util import getQueryParams
 
 class Achewood(BasicComicModule):
     latestUrl = 'http://www.achewood.com/'
@@ -11,6 +10,4 @@ class Achewood(BasicComicModule):
     help = 'Index format: mmddyyyy'
 
     def getFilename(self, imageUrl, pageUrl):
-        queryString = urllib.splitquery(imageUrl)[1]
-        attribs = cgi.parse_qs(queryString)
-        return attribs['date'][0]
+        return getQueryParams(imageUrl)['date'][0]
