@@ -2,7 +2,7 @@ import re
 from dosage.modules.helpers.BasicComicModule import BasicComicModule
 
 class AsIf(BasicComicModule):
-    latestUrl = 'http://www.asifcomic.com/main.html'
+    latestUrl = 'http://asifcomic.com/404.html'
     imageUrl = 'http://www.asifcomic.com/%s.html'
     imageSearch = re.compile(r'<img src="((?:\.\./)*strips/\d+\..+?)"')
     prevSearch = re.compile(r'<a href="(?:\.\./)*(\d+\..+?)"><img[^>]*src="(?:\.\./)*previous\.jpg"', re.MULTILINE | re.IGNORECASE)
