@@ -2,8 +2,8 @@ import re
 from dosage.modules.helpers.BasicComicModule import BasicComicModule
 
 class BiggerThanCheeses(BasicComicModule):
-    latestUrl = 'http://btc.bolloxcomics.co.uk/index.php'
-    imageUrl = 'http://btc.bolloxcomics.co.uk/index.php?comic=%s'
+    latestUrl = 'http://www.biggercheese.com'
+    imageUrl = 'http://www.biggercheese.com/index.php?comic=%s'
     imageSearch = re.compile(r'<img src="(comics/\d{4}.png)" alt="[^"]+">')
     prevSearch = re.compile(r'<a href="(index\.php\?comic=\d+)"><img src="back.png" ')
     help = 'Index format: n (unpadded)'
