@@ -4,6 +4,6 @@ from dosage.modules.helpers.BasicComicModule import BasicComicModule
 class BoyOnAStickAndSlither(BasicComicModule):
     latestUrl = 'http://www.boasas.com/'
     imageUrl = 'http://www.boasas.com/?c=%s'
-    imageSearch = re.compile(r'<td width="\d+" height="\d+" rowspan="\d+"><img src="(boasas/\d+\..+?)"', re.IGNORECASE)
-    prevSearch = re.compile(r'<div align="center"><a href="(\?c=\d+)"><img src="images/next_a\.gif"', re.IGNORECASE)
+    imageSearch = re.compile(r'"(boasas/\d+\..+?)"', re.IGNORECASE)
+    prevSearch = re.compile(r'<a href="(.*?)">.*?arrow_left', re.IGNORECASE)
     help = 'Index format: n (unpadded)'
