@@ -11,9 +11,10 @@ class CloneManga(BasicComicModule, BounceMixin):
     submodules = {
         'AprilAndMay': 'http://manga.clone-army.org/anm.php',
         'Kanami': 'http://manga.clone-army.org/kanami.php',
-        'NanasEverydayLife': 'http://manga.clone-army.org/nana.php',
-        'PaperEleven': 'http://manga.clone-army.org/pxi.php',
+        'NanasEverydayLife': 'http://manga.clone-army.org/nana.php?page=78',
+        'PaperEleven': 'http://manga.clone-army.org/pxi.php?page=311',
         'Tomoyo42sRoom': 'http://manga.clone-army.org/t42r.php',
+        'PennyTribute': 'http://manga.clone-army.org/penny.php',
     }
 
     def __init__(self, submodule):
