@@ -5,5 +5,5 @@ class ErrantStory(BasicComicModule):
     latestUrl = 'http://www.errantstory.com/'
     imageUrl = 'http://www.errantstory.com/archive.php?date=%s'
     imageSearch = re.compile(r'<img[^>]+?src="([^"]*?comics/.+?)"', re.IGNORECASE)
-    prevSearch = re.compile(r'<a href="(archive.php\?.+?)"><img src="[^"]*previous_day[^"]*" alt="[^"]*Previous Day[^"]*"', re.IGNORECASE)
+    prevSearch = re.compile(r'<a href="(archive.php\?[^"]+?)"[^>]*><img src="[^"]*previous_day[^"]*" alt="[^"]*Previous Day[^"]*"', re.IGNORECASE)
     help = 'Index format: yyyy-mm-dd'
