@@ -9,6 +9,7 @@ class InkTank(BasicComicModule):
     currentIndexSearch = re.compile(r'<a href=".+?email\.cfm\?send=(\d+)">')
     help = 'Index format: n (unpadded)'
 
+
     submodules = {
         'AngstTechnology': 'http://www.inktank.com/AT/',
         'WeakEndWarriors': 'http://www.inktank.com/WW/',
@@ -23,12 +24,6 @@ class InkTank(BasicComicModule):
         self.name = 'InkTank' + '/' + submodule
 
     def getFilename(self, imageUrl, pageUrl):
-        if pageUrl in self.submodules.values():
-            page = urlopen(pageUrl)
-            data = page.read()
+	name = '20%s-%s' % (imageUrl[-6:-4], imageUrl[-12:-7])
+        return name
 
-            match = self.currentIndexSearch.search(data)
-            if match:
-                return match.group(1)
-            
-        return getQueryParams(pageUrl)['nav'][0]
