@@ -5,9 +5,9 @@ from dosage.modules.helpers.BasicComicModule import BasicComicModule, BounceMixi
 class KiagiSwordscat(BasicComicModule, BounceMixin):
     baseUrl = 'http://kiagi.com/'
     imageUrl = 'http://kiagi.com/archive.php?go=%s'
-    imageSearch = re.compile(r'<IMG SRC="(autonav\.php\?img=[^"]+)" BORDER="0" ALT="comic">')
-    prevSearch = re.compile(r'<A HREF="(archive\.php\?go=\d{8})">&lt;</A>')
-    nextSearch = re.compile(r'<A HREF="(archive\.php\?go=\d{8})">&gt;</A>')
+    imageSearch = re.compile(r'"(autonav.php\?img=.+?)".+?alt="Comic"', re.IGNORECASE)
+    prevSearch = re.compile(r'<A HREF="(archive\.php\?go=\d{8})">&lt;</A>', re.IGNORECASE)
+    nextSearch = re.compile(r'<A HREF="(archive\.php\?go=\d{8})">&gt;</A>', re.IGNORECASE)
     help = 'Index format: yyyymmdd'
 
     def getFilename(self, imageUrl, pageUrl):
