@@ -1,7 +1,6 @@
 import re
-import urllib
-import cgi
 from dosage.modules.helpers.BasicComicModule import BasicComicModule
+from dosage.util import getQueryParams
 
 class MacHall(BasicComicModule):
     latestUrl = 'http://www.machall.com/'
@@ -11,6 +10,4 @@ class MacHall(BasicComicModule):
     help = 'Index format: n (unpadded)'
 
     def getFilename(self, imageUrl, pageUrl):
-        queryString = urllib.splitquery(imageUrl)[1]
-        attribs = cgi.parse_qs(queryString)
-        return attribs['strip_id'][0]
+        return getQueryParams(imageUrl)['strip_id'][0]
