@@ -4,6 +4,6 @@ from dosage.modules.helpers.BasicComicModule import BasicComicModule
 class PastelDefender(BasicComicModule):
     latestUrl = 'http://www.pasteldefender.com/'
     imageUrl = 'http://www.pasteldefender.com/%s.html'
-    imageSearch = re.compile(r'<FONT COLOR="ORCHID"><IMG SRC="(images/[^"]+)" WIDTH="742" HEIGHT="990"')
+    imageSearch = re.compile(r'<IMG SRC="(images/[^"]+)" WIDTH="742" HEIGHT="990"')
     prevSearch = re.compile(r'<A HREF="([^"]+)"><IMG SRC="images/back\.gif"')
     help = 'Index format: nnn'
