@@ -6,7 +6,7 @@ from dosage.modules.helpers.BasicComicModule import BounceMixin
 from dosage.util import getQueryParams
 
 class PiledHigherAndDeeper(BasicComicModule, BounceMixin):
-    latestUrl = 'http://www.phdcomics.com/comics/archive.php'
+    baseUrl = 'http://www.phdcomics.com/comics/archive.php'
     imageUrl = 'http://www.phdcomics.com/comics/archive.php?comicid=%s'
     imageSearch = re.compile(r'<img src=(http://www\.phdcomics\.com/comics/archive/phd\d+s?\.gif) border=5 align=top>')
     prevSearch = re.compile(r'<a href=(archive\.php\?comicid=\d+)><img height=52 width=49 src=images/prev_button\.gif border=0 align=middle>')
