@@ -4,6 +4,6 @@ from dosage.modules.helpers.BasicComicModule import BasicComicModule
 class Qwantz(BasicComicModule):
     latestUrl = 'http://www.qwantz.com/'
     imageUrl = 'http://www.qwantz.com/%s.html'
-    imageSearch = re.compile(r'<img src="(comics/comic\d+-\d+\.png)"')
-    prevSearch = re.compile(r'<a href="(\d{8}\.html)">previous</a>')
+    imageSearch = re.compile(r'"(/comics/.+?)"')
+    prevSearch = re.compile(r'"(index.pl\?comic=[^"\r\n]+)">previous')
     help = 'Index format: yyyymmdd'
