@@ -4,6 +4,6 @@ from dosage.modules.helpers.BasicComicModule import BasicComicModule
 class SluggyFreelance(BasicComicModule):
     latestUrl = 'http://www.sluggy.com/'
     imageUrl = 'http://www.sluggy.com/daily.php?date=%s'
-    imageSearch = re.compile(r'<img.+?src="(http://pics\.sluggy\.com/comics/\d{6}.+?)"')
-    prevSearch = re.compile(r'<a href="(http://sluggy\.com/daily\.php\?date=\d{6})"><img alt="Go to the previous comic"')
+    imageSearch = re.compile(r'<img[^>]+src="((?:http://www\.sluggy\.com|\.\.)/images/comics/\d{6}.*?\..+?)"')
+    prevSearch = re.compile(r'<a href="(http://www\.sluggy\.com/daily\.php\?date=\d{6})"><img border="." src="[^"]+" alt="Previous Comic">')
     help = 'Index format: yymmdd'
