@@ -3,8 +3,8 @@ from dosage.modules.helpers.BasicComicModule import BasicComicModule, BounceMixi
 
 class SmackJeeves(BasicComicModule, BounceMixin):
     imageSearch = re.compile(r'<img src="(http://www\.smackjeeves\.com/images/uploaded/comics/[^"]*)"', re.IGNORECASE)
-    prevSearch = re.compile(r'<a href="(/comics/\d+/[^"]*)"><img[^>]*alt="< Previous"', re.IGNORECASE)
-    nextSearch = re.compile(r'<a href="(/comics/\d+/[^"]*)"><img[^>]*alt="Next >"', re.IGNORECASE)
+    prevSearch = re.compile(r'<a href="(/comics/\d+/[^"]*)(:?\?PHPSESSID=[a-f0-9]*)"><img[^>]*alt="< Previous"', re.IGNORECASE)
+    nextSearch = re.compile(r'<a href="(/comics/\d+/[^"]*)(:?\?PHPSESSID=[a-f0-9]*)"><img[^>]*alt="Next >"', re.IGNORECASE)
     help = 'Index format: nnnn (some increasing number)'
 
     submodules = {
@@ -17,7 +17,6 @@ class SmackJeeves(BasicComicModule, BounceMixin):
         'mpmcomic': 1,
         'nlmo-project': 1,
         'paranoidloyd': 1,
-        'stuckinside': 1,
         'thatdreamagain': 1,
         'wowcomics': 1,
         'xiongwulegend': 1,
