@@ -5,5 +5,5 @@ class TheWotch(BasicComicModule):
     latestUrl = 'http://www.thewotch.com/'
     imageUrl = 'http://www.thewotch.com/?epDate=%s'
     imageSearch = re.compile(r"<img.+?src='(comics/.+?)'", re.IGNORECASE)
-    prevSearch = re.compile(r"<a href='(\?epDate=\d+-\d+-\d+)'>\n*<img src='graphics/cassieNavNormal", re.IGNORECASE)
+    prevSearch = re.compile(r"<link rel='Previous' href='(\?epDate=\d+-\d+-\d+)'", re.IGNORECASE)
     help = 'Index format: yyyy-mm-dd'
