@@ -1,7 +1,6 @@
 import re
-import urllib
-import cgi
 from dosage.modules.helpers.BasicComicModule import BasicComicModule, BounceMixin
+from dosage.util import getQueryParams
 
 class UserFriendly(BasicComicModule, BounceMixin):
     baseUrl = 'http://ars.userfriendly.org/cartoons/?mode=classic'
@@ -12,6 +11,4 @@ class UserFriendly(BasicComicModule, BounceMixin):
     help = 'Index format: yyyymmdd'
 
     def getFilename(self, imageUrl, pageUrl):
-        queryString = urllib.splitquery(pageUrl)[1]
-        attribs = cgi.parse_qs(queryString)
-        return 'uf%s' % (attribs['id'][0][2:],)
+        return 'uf%s' % (getQueryParams(pageUrl)['id'][0][2:],)
