@@ -5,5 +5,5 @@ class WhiteNinja(BasicComicModule):
     latestUrl = 'http://www.whiteninjacomics.com/comics.shtml'
     imageUrl = 'http://www.whiteninjacomics.com/comics/%s.shtml'
     imageSearch = re.compile(r'<img src=(/images/comics/(?!t-).+?\.gif) border=0', re.IGNORECASE)
-    prevSearch = re.compile(r'<a href=(/comics/.+?\.shtml) onfocus="this.blur\(\);"><img src=/images/previous.jpg border=0')
+    prevSearch = re.compile(r'(/comics/.+?shtml).+?previous')
     help = 'Index format: s (comic name)'
