@@ -18,4 +18,4 @@ class PHPComicModule(BasicComicModule):
         BasicComicModule.__init__(self)
         self.latestUrl = self.basePath + (self.latestUrl or '')
         self.imageUrl =  self.basePath + 'daily.php?date=%s'
-        self.imageSearch = re.compile(r'<img alt="[^"]+" src="(%scomics/\d{6}\..+?)">' % (self.basePath,), re.IGNORECASE)
+        self.imageSearch = re.compile(r'<img alt=[^>]+ src="(%scomics/\d{6}\..+?)">' % (self.basePath,), re.IGNORECASE)
