@@ -1,6 +1,6 @@
 from __future__ import division
 
-import urllib, urllib2
+import urllib, urllib2, urlparse
 import sys
 import struct
 import array
@@ -65,7 +65,18 @@ def fetchManyUrls(url, regexes):
 
     return xformedGroups
 
+def normalizeUrl(url):
+    '''Removes any leading empty segments to avoid breaking urllib2.'''
+    pu = list(urlparse.urlparse(url))
+    segments = pu[2].split('/')
+    while segments and segments[0] == '':
+        del segments[0]
+    pu[2] = '/' + '/'.join(segments)
+    return urlparse.urlunparse(pu)
+
 def urlopen(url, referrer=None, retries=5):
+    # Work around urllib2 brokenness
+    url = normalizeUrl(url)
     req = urllib2.Request(url)
     if referrer:
         req.add_header('Referrer', referrer)
@@ -137,4 +148,5 @@ def getRelativePath(basepath, path):
 
 def getQueryParams(url):
     query = urllib.splitquery(url)[-1]
+    out.write('Extracting query parameters from %r (%r)...' % (url, query), 3)
     return cgi.parse_qs(query)
